@@ -1,19 +1,7 @@
 /*
-    Copyright (C) 2012  Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+    SPDX-FileCopyrightText: 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #ifndef MATCHESSOLVER_H
@@ -21,8 +9,8 @@
 
 #include <KJob>
 
-#include <kpeople/kpeople_export.h>
 #include "match_p.h"
+#include <kpeople/kpeople_export.h>
 
 class QUrl;
 class QModelIndex;
@@ -63,8 +51,8 @@ private Q_SLOTS:
     void startMatching();
 
 private:
-    QList<Match> m_matches;
-    PersonsModel *m_model;
+    const QList<Match> m_matches;
+    PersonsModel *const m_model;
 };
 }
 
